@@ -242,7 +242,7 @@ class Database(object):
     def _request(self, d, method, path, body, headers, protocol, keepOnTrying=False, returnOnError=False, **ka):
         url = self._url+"/"+self._name
         if path:
-            url += "/"+urllib.quote(path, "")
+            url += "/"+urllib.quote(path)
 
         if len(ka) > 0:
             kv = dict()
